@@ -231,6 +231,16 @@ class Agent:
             timeout=timeout,
         )
 
+    def should_continue_as_new(self) -> bool:
+        """Check if the agent should continue as new.
+
+        Example:
+
+            .. code-block:: python
+
+                await agent.should_continue_as_new()
+        """
+        return temporal_workflow.info().is_continue_as_new_suggested()
     async def agent_continue_as_new(self, *args: Any, **kwargs: Any) -> None:
         """Resets the agent to start fresh when its history becomes too large.
 
